@@ -82,7 +82,6 @@ class FilterStructs(object):
             if isinstance(value, list):
                 if len(value) > 0:
                     or_filters = []
-
                     for match in value:
                         or_filters.append(u'({0})'.format(match))
 
@@ -109,6 +108,20 @@ class FilterStructs(object):
                 }
             }
 
+    def or_filter(self, *args):
+        if self.type == 'filter':
+            return self.type, {
+                'or': args
+            }
+        else:
+            return self.type, {
+                'filtered': {
+                    'filter': {
+                        'or': args
+                    }
+                }
+            }
+
 
 # Query structures
 # inherits filters due to overlap
